@@ -133,7 +133,10 @@ class NumericRegressionFixture(object):
                 diff_ids = np.where(not_close_mask)[0]
                 diff_obtained_data = obtained_column[diff_ids]
                 diff_expected_data = expected_column[diff_ids]
-                diffs = np.abs(obtained_column - expected_column)[diff_ids]
+                if data_type == np.bool:
+                    diffs = np.logical_xor(obtained_column, expected_column)[diff_ids]
+                else:
+                    diffs = np.abs(obtained_column - expected_column)[diff_ids]
 
                 comparison_table = pd.concat(
                     [diff_obtained_data, diff_expected_data, diffs], axis=1
@@ -249,7 +252,13 @@ class NumericRegressionFixture(object):
             if not fill_different_shape_with_nan:
                 assert (
                     False
-                ), "Data dict with different array lengths will not be accepted." "Try setting fill_different_shape_with_nan=True."
+                ), "Data dict with different array lengths will not be accepted. Try setting fill_different_shape_with_nan=True."
+            elif len(data_dict) > 1 and not all(
+                np.issubdtype(a.dtype, np.floating) for a in data_dict.values()
+            ):
+                raise TypeError(
+                    'Checking multiple arrays with different shapes are not supported for non-float arrays" in obtained_error_msg.'
+                )
             else:
                 max_size = max(data_shapes)
                 for k, obj in data_dict.items():
