@@ -161,32 +161,28 @@ def test_different_data_types(num_regression, no_regen):
     num_regression.check({"data1": data1})
 
     data2 = np.array(["a"] * 10)
-    with pytest.raises(AssertionError) as excinfo:
+    with pytest.raises(
+        AssertionError,
+        match="Data type for data data1 of obtained and expected are not the same.",
+    ):
         num_regression.check({"data1": data2})
-    obtained_error_msg = str(excinfo.value)
-    assert (
-        "Data type for data data1 of obtained and expected are not the same."
-        in obtained_error_msg
-    )
 
 
 def test_n_dimensions(num_regression, no_regen):
     data1 = np.ones(shape=(10, 10), dtype=np.int)
-    with pytest.raises(AssertionError) as excinfo:
+    with pytest.raises(
+        AssertionError,
+        match="Only 1D arrays are supported on num_data_regression fixture.",
+    ):
         num_regression.check({"data1": data1})
-    obtained_error_msg = str(excinfo.value)
-    assert (
-        "Only 1D arrays are supported on num_data_regression fixture."
-        in obtained_error_msg
-    )
 
 
 def test_arrays_with_different_sizes(num_regression, no_regen):
     data1 = np.ones(10, dtype=np.float64)
-    with pytest.raises(AssertionError) as excinfo:
+    with pytest.raises(
+        AssertionError, match="Obtained and expected data shape are not the same."
+    ):
         num_regression.check({"data1": data1})
-    obtained_error_msg = str(excinfo.value)
-    assert "Obtained and expected data shape are not the same." in obtained_error_msg
 
 
 def test_integer_values_smoke_test(num_regression, no_regen):
@@ -197,3 +193,59 @@ def test_integer_values_smoke_test(num_regression, no_regen):
 def test_number_formats(num_regression, no_regen):
     data1 = np.array([1.2345678e50, 1.2345678e-50, 0.0])
     num_regression.check({"data1": data1})
+
+
+def test_fill_different_shape_with_nan(num_regression, no_regen):
+    data1 = np.ones(5, dtype=np.float64)
+    data2 = np.ones(2, dtype=np.float32)
+    data3 = np.ones(6, dtype=np.float16)
+    num_regression.check({"data1": data1, "data2": data2, "data3": data3})
+
+
+def test_fill_different_shape_with_nan_false(num_regression, no_regen):
+    data1 = np.ones(5, dtype=np.float64)
+    data2 = np.ones(2, dtype=np.float32)
+    data3 = np.ones(6, dtype=np.float16)
+    with pytest.raises(
+        AssertionError,
+        match="Data dict with different array lengths will not be accepted.",
+    ):
+        num_regression.check(
+            {"data1": data1, "data2": data2, "data3": data3},
+            fill_different_shape_with_nan=False,
+        )
+
+
+def test_fill_different_shape_with_nan_for_non_float_array(num_regression, no_regen):
+    data1 = np.ones(5, dtype=np.int32)
+    data2 = np.ones(2, dtype=np.float64)
+    data3 = np.ones(6, dtype=np.float64)
+    with pytest.raises(
+        TypeError,
+        match="Checking multiple arrays with different shapes are not supported for non-float arrays",
+    ):
+        num_regression.check({"data1": data1, "data2": data2, "data3": data3})
+
+
+def test_bool_array(num_regression, no_regen):
+    data1 = np.array([True, True, True], dtype=np.bool)
+    with pytest.raises(AssertionError) as excinfo:
+        num_regression.check({"data1": data1})
+    obtained_error_msg = str(excinfo.value)
+    expected = "\n".join(
+        [
+            "Values are not sufficiently close.",
+            "To update values, use --force-regen option.",
+        ]
+    )
+    assert expected in obtained_error_msg
+    expected = "\n".join(
+        [
+            "data1:",
+            "   obtained_data1  expected_data1  diff",
+            "0            True           False  True",
+            "1            True           False  True",
+            "2            True           False  True",
+        ]
+    )
+    assert expected in obtained_error_msg
